"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGlobalSettings = exports.setGlobalSettings = exports.getComponentSettings = exports.setComponentSettings = exports.Scope = exports.Host = exports.State = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixAppSettingsV1Settings = __importStar(require("./app-settings-v1-settings-app-settings.http.js"));
/** The state of the settings (Saved or Published) */
var State;
(function (State) {
    /** Not relevant */
    State["NR"] = "NR";
    State["SAVED"] = "SAVED";
    State["PUBLISHED"] = "PUBLISHED";
})(State || (exports.State = State = {}));
/** The host in which the settings are displayed */
var Host;
(function (Host) {
    Host["NA"] = "NA";
    Host["VIEWER"] = "VIEWER";
    Host["BUSINESS_MANAGER"] = "BUSINESS_MANAGER";
    Host["ONE_APP"] = "ONE_APP";
})(Host || (exports.Host = Host = {}));
/** scope of settings when creating/updating; */
var Scope;
(function (Scope) {
    /** multiple instances of a tpa can share same settings; */
    Scope["APP"] = "APP";
    /** scoped to a single component of an app; */
    Scope["COMPONENT"] = "COMPONENT";
})(Scope || (exports.Scope = Scope = {}));
/**
 * Set component settings by componentId
 * @param componentId - The component Id
 * @public
 * @documentationMaturity preview
 * @requiredField componentId
 * @fqn com.wix.fed.settings.AppSettingsService.SetComponentSettings
 */
async function setComponentSettings(componentId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        componentId: componentId,
        settings: options?.settings,
        state: options?.state,
        host: options?.host,
        translations: options?.translations,
        states: options?.states,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.setComponentSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                componentId: '$[0]',
                settings: '$[1].settings',
                state: '$[1].state',
                host: '$[1].host',
                translations: '$[1].translations',
                states: '$[1].states',
            },
            singleArgumentUnchanged: false,
        }, ['componentId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.setComponentSettings = setComponentSettings;
/**
 * Get component settings by componentId
 * @param componentId - The component we want data for. Component ids can be from the site or oneApp
 * @public
 * @documentationMaturity preview
 * @requiredField componentId
 * @fqn com.wix.fed.settings.AppSettingsService.GetComponentSettings
 */
async function getComponentSettings(componentId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        componentId: componentId,
        state: options?.state,
        host: options?.host,
        languageKey: options?.languageKey,
        includeGlobalSettings: options?.includeGlobalSettings,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.getComponentSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                componentId: '$[0]',
                state: '$[1].state',
                host: '$[1].host',
                languageKey: '$[1].languageKey',
                includeGlobalSettings: '$[1].includeGlobalSettings',
            },
            singleArgumentUnchanged: false,
        }, ['componentId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getComponentSettings = getComponentSettings;
/**
 * Set global settings by instanceId (extracted from Authorization)
 * @public
 * @documentationMaturity preview
 * @fqn com.wix.fed.settings.AppSettingsService.SetGlobalSettings
 */
async function setGlobalSettings(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        settings: options?.settings,
        componentSettings: options?.componentSettings,
        state: options?.state,
        host: options?.host,
        translations: options?.translations,
        states: options?.states,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.setGlobalSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                settings: '$[0].settings',
                componentSettings: '$[0].componentSettings',
                state: '$[0].state',
                host: '$[0].host',
                translations: '$[0].translations',
                states: '$[0].states',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.setGlobalSettings = setGlobalSettings;
/**
 * Get global settings by instanceId (extracted from Authorization)
 * @public
 * @documentationMaturity preview
 * @fqn com.wix.fed.settings.AppSettingsService.GetGlobalSettings
 */
async function getGlobalSettings(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        state: options?.state,
        host: options?.host,
        includeComponentSettings: options?.includeComponentSettings,
        languageKey: options?.languageKey,
    });
    const reqOpts = ambassadorWixAppSettingsV1Settings.getGlobalSettings(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                state: '$[0].state',
                host: '$[0].host',
                includeComponentSettings: '$[0].includeComponentSettings',
                languageKey: '$[0].languageKey',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getGlobalSettings = getGlobalSettings;
//# sourceMappingURL=app-settings-v1-settings-app-settings.universal.js.map